% La fonction "MC_optionechange" valorise l'option d'échange, en prenant en
% arguments les cours initiaux "A0" et "B0" des actifs A et B ainsi que la
% maturité "T" de l'option, à l'aide de simulations de Monte-Carlo dont le
% nombre "NSIM" est également passé en argument; et affiche le résultat.
function estimateurOpt = MC_optionechange (A0, B0, T, NSIM)
% Déclaration des variables globales utilisées dans cette fonction.
global R
% Il est important d'initialiser toutes les varibales globales, et pas
% seulement "R", dans la mesure où sinon les autres variables globales ne
% seraient pas initialisées pour la fonction "simulation_risqueneutre"...
init_optionechange;
% Somme et somme des carrés des simulations.
somme = 0;
somme2 = 0;
% On lance la boucle de Monte-Carlo.
for i = 1: NSIM
    % Simulation de la valeur finale des cours de A et B sous loi
    % risque-neutre.
    ab_final = simulation_risqueneutre (A0, B0, T);
    % "valeur_finale" est la valeur de l'option à échéance pour la
    % simulation considérée.
    valeur_finale = max (ab_final(1) - ab_final(2), 0);
    somme = somme + valeur_finale;
    somme2 = somme2 + valeur_finale * valeur_finale;
end
% On calcule l'estimateur de Monte-Carlo pour l'espérance de (A_T-B_T)^+ et
% son intervalle de confiance (à 95 %).
moyenne = somme / NSIM;
estimateurEsp = moyenne;
variance = somme2 / NSIM - moyenne * moyenne;
variance_estimateurEsp = variance / NSIM;
fprintf ('Sous la mesure risque-neutre, l''espérance de (A_T-B_T)^+ ');
fprintf ('vaut\n%f ± %f €.\n', estimateurEsp, ...
    1.96 * sqrt (variance_estimateurEsp));
% Il faut encore tenir compte de l'ajustement par le taux sans risque pour
% déterminer la juste valeur de l'option. Notez bien qu'au niveau de la
% variance de l'estimateur, il faut aussi faire un ajustement: cela
% correspond à une application de la première partie de l'exercice 2 (même
% si en l'occurrence le raisonnement est beaucoup plus simple car la
% fonction appliquée à l'espérance est déjà affine).
estimateurOpt = exp (-R * T) * estimateurEsp;
variance_estimateurOpt = exp (-R * T) ^ 2 * variance_estimateurEsp;
fprintf ('On en déduit que la juste valeur de l''option est\n');
fprintf ('%f ± %f €.\n', estimateurOpt, ...
    1.96 * sqrt (variance_estimateurOpt));
end
