% La fonction "simulation_risqueneutre" simule l'évolution /sous la mesure risque-neutre/ des cours des actifs
% A et B sur la durée "T", en partant des conditions initiales respectives
% "A0" et "B0". C'est le même code que "simulation_vraie", à ceci près
% qu'on remplace BETA_A et BETA_B par le taux sans risque R. En outre,
% plutôt que de tracee l'évolution de l'actif, on renvoie les cours
% finaux de A et B (sous la forme d'un 2-vecteur [a, b]);
function ab_final = simulation_risqueneutre (A0, B0, T)
global SIGMA_A1 SIGMA_A2 SIGMA_B1 SIGMA_B2 TAU A_ETOILE R PAS
npas = ceil (T / PAS);
pas = T / npas;
% On n'a plus besoin de stocker en mémoire les cours de A et B, d'où
% disparition des vecteurs "cours_A" et "cours_B" ; ainsi que de "temps"
% puisqu'on ne trace plus le graphique.
a = A0;
b = B0;
for i = 1: npas
    dW1 = sqrt (pas) * randn;
    dW2 = sqrt (pas) * randn;
    dW3 = sqrt (pas) * randn;
    dt = pas;
    a = a + a * (SIGMA_A1 * dW1 + SIGMA_A2 * dW2 + ...
        TAU / (1 + a / A_ETOILE) * dW3 + R * dt);
    b = b + b * (SIGMA_B1 * dW1 + SIGMA_B2 * dW2 + R * dt);
end
ab_final = [a b];
return
end
