% La fonction "simulation_vraie_" simule l'évolution des cours des actifs
% A et B sur la durée "T", en partant des conditions initiales respectives
% "A0" et "B0".
function simulation_vraie (A0, B0, T)
% Déclaration et initialisation des variables globales. (L'initialisation
% est déléguée à la fonction auxiliaire "init_optiondechange").
global SIGMA_A1 SIGMA_A2 SIGMA_B1 SIGMA_B2 TAU A_ETOILE BETA_A BETA_B PAS
init_optionechange;
% Nombre de pas pour la simulation.
npas = ceil (T / PAS);
% Astuce : pour être sûr que le temps final corresponde exactement à T,
% même si ce n'est pas un multiple de PAS, je remplace PAS par un diviseur
% de T.
pas = T / npas;
% Instants considérés, et allocation de mémoire pour les cours de A et de
% B.
temps = pas * (0: npas);
cours_A = zeros (1, npas + 1);
cours_B = zeros (1, npas + 1);
% Initialisation des cours de A et B, dont les valeurs courantes sont resp.
% appelées "a" et "b".
a = A0;
b = B0;
cours_A(1) = a;
cours_B(1) = b;
% Boucle de simulation.
for i = 1: npas
    dW1 = sqrt (pas) * randn;
    dW2 = sqrt (pas) * randn;
    dW3 = sqrt (pas) * randn;
    dt = pas;
    % Notez que l'ordre dans lequel je fais les mises à jour de "a" et "b"
    % importe peu ici, car "a" n'est pas utilisé dans la mise à jour de
    % "b", et vice-versa.
    a = a + a * (SIGMA_A1 * dW1 + SIGMA_A2 * dW2 + ...
        TAU / (1 + a / A_ETOILE) * dW3 + BETA_A * dt);
    b = b + b * (SIGMA_B1 * dW1 + SIGMA_B2 * dW2 + BETA_B * dt);
    cours_A(i + 1) = a;
    cours_B(i + 1) = b;
end
% Tracé de la figure. Entre « hold on » et « hold off », tous les tracés
% auront lieu sur la figure courante.
figure;
hold on;
plot (temps, cours_A, 'b');
plot (temps, cours_B, 'r');
title ('Évolution des cours de A (en bleu) et B (en rouge)');
hold off;
return
end
