% La fonction "MC_ectype" estime l'écart-type d'une variable aléatoire X de
% classe L^4 simulée par la fonction "simul_X", en précisant un intervalle
% de confiance à 5 % (asymptotique). Il s'agit d'une application directe
% des questions 12 et 13 de l'exercice 2.
function MC_ectype (Nsim)
% Il y a 5 sommes à maintenir : les sommes des x^(1) et des x^(2)
% (rappelons qu'ici cela correspond respectivement à X et à X^2), et les
% sommes des produits x^(1)x^(1), x^(1)x^(2) et x^(2)x^(2). Dans le cas
% particulier de cet exrcice, on notera que la somme des x^(2) va en fait
% coïncider avec la somme des x^(1)x^(1).
somme_x1 = 0;
somme_x2 = 0;
somme_x1x1 = 0;
somme_x1x2 = 0;
somme_x2x2 = 0;
% Boucle de Monte-Carlo. Notez que dans la boucle, la fonction f (en
% l'occurrence, f(x_1,x_2) := sqrt(x_2-x_1^2)), qu'on utilise pour
% déterminer l'écart-type à partir des espérances, n'intervient nulle part
% !
for i = 1: Nsim
    % On simule "x1" et "x2" suivant la loi jointe de (X,X^2).
    x = simul_X;
    x1 = x;
    x2 = x ^ 2;
    % On maintient les sommes à jour.
    somme_x1 = somme_x1 + x1;
    somme_x2 = somme_x2 + x2;
    somme_x1x1 = somme_x1x1 + x1 * x1;
    somme_x1x2 = somme_x1x2 + x1 * x2;
    somme_x2x2 = somme_x2x2 + x2 * x2;
end
% On calcule les espérances empiriques (les « E[.] » de l'énoncé).
moy_x1 = somme_x1 / Nsim;
moy_x2 = somme_x2 / Nsim;
moy_x1x1 = somme_x1x1 / Nsim;
moy_x1x2 = somme_x1x2 / Nsim;
moy_x2x2 = somme_x2x2 / Nsim;
% L'estimateur de l'écart-type s'obtient en appliquant f aux estimateurs
% des espérances respectives de X^(1) et X^(2).
estimateur = sqrt (moy_x2 - moy_x1 ^ 2);
% Pour connaitre v-chapeau, on a besoin des dérivées partielles de f,
% évaluées en (moy_x1,moy_x2). Le calcul des dérivées partielles en
% question est un simple exercice de niveau hypotaupe.
diff1 = -moy_x1 / sqrt (moy_x2 - moy_x1 ^ 2);
diff2 = 1 / 2 / sqrt (moy_x2 - moy_x1 ^ 2);
% On applique la formule de la question 12 pour calculer v-chapeau. Noter
% que deux des quatre termes sont identiques, ce qui explique le « 2* »
% devant le second terme ci-dessous.
vchapeau = (moy_x1x1 - moy_x1 * moy_x1) * diff1 * diff1 + ...
    2 * (moy_x1x2 - moy_x1 * moy_x2) * diff1 * diff2 + ...
    (moy_x2x2 - moy_x2 * moy_x2) * diff2 * diff2;
% Attention; ce n'est pas v-chapeau lui-même qui est (un estimateur de) la
% variance effective de notre estimateur: c'est v-chapeau/N...
var_estr = vchapeau / Nsim;
% On affiche le résultat.
fprintf ('L''écart-type de ma variable aléatoire est estimé à ');
fprintf ('%f ± %f\n', estimateur, 1.96 * sqrt (var_estr));
return
end
